# DRAGON

## Purpose
- Provide convenient higher-level interfaces for faster devops

## Why the name
- nogard is DRAGON backwards
- Moves on from the incompentence of COBRA, almost in a backwards fashion

## When to expect
- Give it about a month until the first prototype
